@@ -25,7 +25,7 @@
  * list of people on the gedit Team.  
  * See the ChangeLog files for a list of changes. 
  *
- * $Id: gedit-ui.h,v 1.13 2006/06/18 09:05:20 paolo Exp $
+ * $Id: gedit-ui.h 6820 2009-01-07 15:06:18Z icq $
  */
 
 #ifndef __GEDIT_UI_H__
@@ -39,11 +39,6 @@
 
 #include "gedit-commands.h"
 
-/* FIXME: remove it when bumping dependency to GTK 2.10 */
-#ifndef GTK_STOCK_SELECT_ALL
-#	define GTK_STOCK_SELECT_ALL NULL
-#endif
-
 G_BEGIN_DECLS
 
 static const GtkActionEntry gedit_always_sensitive_menu_entries[] =
@@ -73,7 +68,12 @@ static const GtkActionEntry gedit_always_sensitive_menu_entries[] =
 	{"HelpContents", GTK_STOCK_HELP, N_("_Contents"), "F1",
 	 N_("Open the gedit manual"), G_CALLBACK (_gedit_cmd_help_contents) },
 	{ "HelpAbout", GTK_STOCK_ABOUT, NULL, NULL,
-	 N_("About this application"), G_CALLBACK (_gedit_cmd_help_about) }
+	 N_("About this application"), G_CALLBACK (_gedit_cmd_help_about) },
+	
+	/* Fullscreen toolbar */
+	{ "LeaveFullscreen", GTK_STOCK_LEAVE_FULLSCREEN, NULL,
+	  NULL, N_("Leave fullscreen mode"),
+	  G_CALLBACK (_gedit_cmd_view_leave_fullscreen_mode) }
 };
 
 static const GtkActionEntry gedit_menu_entries[] =
@@ -85,7 +85,7 @@ static const GtkActionEntry gedit_menu_entries[] =
 	  N_("Save the current file with a different name"), G_CALLBACK (_gedit_cmd_file_save_as) },
 	{ "FileRevert", GTK_STOCK_REVERT_TO_SAVED, NULL, NULL,
 	  N_("Revert to a saved version of the file"), G_CALLBACK (_gedit_cmd_file_revert) },
-	{ "FilePageSetup", NULL, N_("Page Set_up..."), NULL,
+	{ "FilePageSetup", GTK_STOCK_PAGE_SETUP, N_("Page Set_up..."), NULL,
 	  N_("Setup the page settings"), G_CALLBACK (_gedit_cmd_file_page_setup) },
 	{ "FilePrintPreview", GTK_STOCK_PRINT_PREVIEW, N_("Print Previe_w"),"<control><shift>P",
 	  N_("Print preview"), G_CALLBACK (_gedit_cmd_file_print_preview) },
@@ -126,8 +126,8 @@ static const GtkActionEntry gedit_menu_entries[] =
 	  N_("Clear highlighting of search matches"), G_CALLBACK (_gedit_cmd_search_clear_highlight) },
 	{ "SearchGoToLine", GTK_STOCK_JUMP_TO, N_("Go to _Line..."), "<control>I",
 	  N_("Go to a specific line"), G_CALLBACK (_gedit_cmd_search_goto_line) },
-	{ "SearchInteractiveSearch", GTK_STOCK_FIND, N_("Interactive search..."), "<control>K",
-	  N_("Interactively search for text"), G_CALLBACK (_gedit_cmd_search_interactive_search) },
+	{ "SearchIncrementalSearch", GTK_STOCK_FIND, N_("_Incremental Search..."), "<control>K",
+	  N_("Incrementally search for text"), G_CALLBACK (_gedit_cmd_search_incremental_search) },
 
 	/* Documents menu */
 	{ "FileSaveAll", GTK_STOCK_SAVE, N_("_Save All"), "<shift><control>L",
@@ -159,7 +159,10 @@ static const GtkToggleActionEntry gedit_always_sensitive_toggle_menu_entries[] =
 	  G_CALLBACK (_gedit_cmd_view_show_statusbar), TRUE },
 	{ "ViewSidePane", NULL, N_("Side _Pane"), "F9",
 	  N_("Show or hide the side pane in the current window"),
-	  G_CALLBACK (_gedit_cmd_view_show_side_pane), FALSE }
+	  G_CALLBACK (_gedit_cmd_view_show_side_pane), FALSE },
+	{ "ViewFullscreen", GTK_STOCK_FULLSCREEN, NULL, "F11",
+	  N_("Edit text at fullscreen"),
+	  G_CALLBACK (_gedit_cmd_view_toggle_fullscreen_mode), FALSE }
 };
 
 static const GtkToggleActionEntry gedit_toggle_menu_entries[] =
