@@ -17,7 +17,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- * $Id: gedit-time-plugin.c 6379 2008-08-10 16:40:21Z pborelli $
+ * $Id: gedit-time-plugin.c 6928 2009-03-01 15:26:54Z pborelli $
  */
 
 /*
@@ -73,7 +73,9 @@ static const gchar *formats[] =
 	"%a %d %b %Y %H:%M:%S",
 	"%d/%m/%Y",
 	"%d/%m/%y",
-	"%D",
+#ifndef G_OS_WIN32
+	"%D", /* This one is not supported on win32 */
+#endif
 	"%A %d %B %Y",
 	"%A %B %d %Y",
 	"%Y-%m-%d",
@@ -741,6 +743,8 @@ static TimeConfigureDialog *
 get_configure_dialog (GeditTimePlugin *plugin)
 {
 	TimeConfigureDialog *dialog = NULL;
+	gchar *data_dir;
+	gchar *ui_file;
 	GtkWidget *content;
 	GtkWidget *viewport;
 	GeditTimePluginPromptType prompt_type;
@@ -775,7 +779,9 @@ get_configure_dialog (GeditTimePlugin *plugin)
 
 	g_return_val_if_fail (dialog->dialog != NULL, NULL);
 
-	ret = gedit_utils_get_ui_objects (GEDIT_UIDIR "time.ui",
+	data_dir = gedit_plugin_get_data_dir (GEDIT_PLUGIN (plugin));
+	ui_file = g_build_filename (data_dir, "time.ui", NULL);
+	ret = gedit_utils_get_ui_objects (ui_file,
 					  root_objects,
 					  &error_widget,
 					  "time_dialog_content", &content,
@@ -788,6 +794,9 @@ get_configure_dialog (GeditTimePlugin *plugin)
 					  "custom_format_example", &dialog->custom_format_example,
 					  NULL);
 
+	g_free (data_dir);
+	g_free (ui_file);
+
 	if (!ret)
 	{
 		gtk_box_pack_start_defaults (GTK_BOX (GTK_DIALOG (dialog->dialog)->vbox),
@@ -917,13 +926,21 @@ get_choose_format_dialog (GtkWindow                 *parent,
 			  GeditTimePlugin           *plugin)
 {
 	ChooseFormatDialog *dialog;
+	gchar *data_dir;
+	gchar *ui_file;
 	GtkWidget *error_widget;
 	gboolean ret;
 	gchar *sf, *cf;
+	GtkWindowGroup *wg = NULL;
+	
+	if (parent != NULL)
+		wg = parent->group;
 
 	dialog = g_new0 (ChooseFormatDialog, 1);
 
-	ret = gedit_utils_get_ui_objects (GEDIT_UIDIR "time.ui",
+	data_dir = gedit_plugin_get_data_dir (GEDIT_PLUGIN (plugin));
+	ui_file = g_build_filename (data_dir, "time.ui", NULL);
+	ret = gedit_utils_get_ui_objects (ui_file,
 					  NULL,
 					  &error_widget,
 					  "choose_format_dialog", &dialog->dialog,
@@ -934,17 +951,44 @@ get_choose_format_dialog (GtkWindow                 *parent,
 					  "custom_format_example", &dialog->custom_format_example,
 					  NULL);
 
+	g_free (data_dir);
+	g_free (ui_file);
+
 	if (!ret)
 	{
-		gedit_warning (parent,
-			       gtk_label_get_label (GTK_LABEL (error_widget)));
+		GtkWidget *err_dialog;
 
-		g_free (dialog);
-		gtk_widget_destroy (error_widget);
+		err_dialog = gtk_dialog_new_with_buttons (NULL,
+			parent,
+			GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
+			GTK_STOCK_OK, GTK_RESPONSE_ACCEPT,
+			NULL);
+
+		if (wg != NULL)
+			gtk_window_group_add_window (wg, GTK_WINDOW (err_dialog));
+
+		gtk_window_set_resizable (GTK_WINDOW (err_dialog), FALSE);
+		gtk_dialog_set_has_separator (GTK_DIALOG (err_dialog), FALSE);
+		gtk_dialog_set_default_response (GTK_DIALOG (err_dialog), GTK_RESPONSE_OK);
+
+		gtk_container_add (GTK_CONTAINER (gtk_dialog_get_content_area (GTK_DIALOG (err_dialog))),
+				   error_widget);
+
+		g_signal_connect (G_OBJECT (err_dialog),
+				  "response",
+				  G_CALLBACK (gtk_widget_destroy),
+				  NULL);
+
+		gtk_widget_show_all (err_dialog);
 
 		return NULL;
 	}
 
+	gtk_window_group_add_window (wg,
+			     	     GTK_WINDOW (dialog->dialog));
+	gtk_window_set_transient_for (GTK_WINDOW (dialog->dialog), parent);
+	gtk_window_set_modal (GTK_WINDOW (dialog->dialog), TRUE);
+
 	sf = get_selected_format (plugin);
 	create_formats_list (dialog->list, sf, plugin);
 	g_free (sf);
@@ -1095,32 +1139,23 @@ time_cb (GtkAction  *action,
 	}
         else
         {
-        	GtkWindowGroup *wg;
 		ChooseFormatDialog *dialog;
 
 		dialog = get_choose_format_dialog (GTK_WINDOW (data->window),
 						   prompt_type,
 						   data->plugin);
-		g_return_if_fail (dialog != NULL);
+		if (dialog != NULL)
+		{
+			dialog->buffer = buffer;
+			dialog->plugin = data->plugin;
 
-		wg = gedit_window_get_group (data->window);
+			g_signal_connect (dialog->dialog,
+					  "response",
+					  G_CALLBACK (choose_format_dialog_response_cb),
+					  dialog);
 
-		gtk_window_group_add_window (wg,
-				     	     GTK_WINDOW (dialog->dialog));
-
-		gtk_window_set_transient_for (GTK_WINDOW (dialog->dialog),
-					      GTK_WINDOW (data->window));
-		gtk_window_set_modal (GTK_WINDOW (dialog->dialog), TRUE);
-
-		dialog->buffer = buffer;
-		dialog->plugin = data->plugin;
-
-		g_signal_connect (dialog->dialog,
-				  "response",
-				  G_CALLBACK (choose_format_dialog_response_cb),
-				  dialog);
-
-		gtk_widget_show (GTK_WIDGET (dialog->dialog));
+			gtk_widget_show (GTK_WIDGET (dialog->dialog));
+		}
 
 		return;
 	}
